package com.atguigu.ssyx.activity.service;

import com.atguigu.ssyx.model.activity.CouponInfo;
import com.atguigu.ssyx.model.order.CartInfo;
import com.atguigu.ssyx.vo.activity.CouponRuleVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 优惠券信息 服务类
 * </p>
 *
 * @author atguigu
 * @since 2023-09-17
 */
public interface CouponInfoService extends IService<CouponInfo> {


    /**
     * 获取分页列表
     *
     * @param page
     * @param limit
     * @return
     */
    IPage<CouponInfo> selectPage(Long page, Long limit);

    /**
     * 根据ID查询优惠券
     *
     * @param id
     * @return
     */
    CouponInfo getCouponInfo(Long id);

    /**
     * 根据优惠卷id获取优惠券规则列表
     *
     * @param id
     * @return
     */
    Map<String, Object> findCouponRuleList(Long id);

    /**
     * 新增优惠券规则
     *
     * @param couponRuleVo
     */
    void saveCouponRule(CouponRuleVo couponRuleVo);

    /**
     * 根据关键字获取sku列表，活动使用
     *
     * @param keyword
     * @return
     */
    List<CouponInfo> findCouponByKeyword(String keyword);

    /**
     * 根据skuId+userId查询优惠卷信息
     *
     * @param skuId
     * @param userId
     * @return
     */

    List<CouponInfo> findCouponInfoList(Long skuId, Long userId);

    /**
     * 获取购物车可以使用优惠卷列表
     *
     * @param cartInfoList
     * @param userId
     * @return
     */
    List<CouponInfo> findCartCouponInfo(List<CartInfo> cartInfoList, Long userId);

    /**
     * 获取购物车对应优惠券数据
     *
     * @param cartInfoList
     * @param couponId
     * @return
     */
    CouponInfo findRangeSkuIdList(List<CartInfo> cartInfoList, Long couponId);

    /**
     * 更新优惠卷使用状态
     *
     * @param couponId
     * @param userId
     * @param orderId
     */
    void updateCouponInfoUseStatus(Long couponId, Long userId, Long orderId);
}
