package com.atguigu.ssyx.product.service;

import com.atguigu.ssyx.model.product.SkuInfo;
import com.atguigu.ssyx.vo.product.SkuInfoQueryVo;
import com.atguigu.ssyx.vo.product.SkuInfoVo;
import com.atguigu.ssyx.vo.product.SkuStockLockVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;

/**
 * <p>
 * sku信息 服务类
 * </p>
 *
 * @author atguigu
 * @since 2023-09-15
 */
public interface SkuInfoService extends IService<SkuInfo> {
    /**
     * 获取sku分页列表
     *
     * @param pageParam
     * @param skuInfoQueryVo
     * @return
     */
    IPage<SkuInfo> selectPage(Page<SkuInfo> pageParam, SkuInfoQueryVo skuInfoQueryVo);

    /**
     * 新增商品sku信息
     *
     * @param skuInfoVo
     */
    void saveSkuInfo(SkuInfoVo skuInfoVo);

    /**
     * 根据id获取商品sku信息
     *
     * @param id
     * @return
     */
    SkuInfoVo getSkuInfoVo(Long id);

    void updateSkuInfo(SkuInfoVo skuInfoVo);

    /**
     * a商品审核
     *
     * @param skuId
     * @param status
     */
    void check(Long skuId, Integer status);

    /**
     * 商品上/下架
     *
     * @param skuId
     * @param status
     */

    void publish(Long skuId, Integer status);

    /**
     * 新人专享
     *
     * @param skuId
     * @param status
     */
    void isNewPerson(Long skuId, Integer status);

    /**
     * 根据id列表删除商品sku信息
     *
     * @param idList
     */
    void deleteByIds(List<Long> idList);

    /**
     * 根据id删除商品sku信息
     *
     * @param id
     */
    void deleteById(Long id);

    /**
     * 批量获取sku信息
     *
     * @param skuIdList
     * @return
     */
    List<SkuInfo> findSkuInfoList(List<Long> skuIdList);

    /**
     * 根据关键字获取sku列表
     *
     * @param keyword
     * @return
     */
    List<SkuInfo> findSkuInfoByKeyword(String keyword);

    /**
     * 获取新人专享商品
     *
     * @return
     */
    List<SkuInfo> findNewPersonSkuInfoList();

    /**
     * 验证和锁定库存
     *
     * @param skuStockLockVoList
     * @param orderNo
     * @return
     */
    Boolean checkAndLock(List<SkuStockLockVo> skuStockLockVoList, String orderNo);

    /**
     * 扣减库存成功，更新订单状态
     *
     * @param orderNo
     */
    void minusStock(String orderNo);
}
